set key graph 0.4,graph 0.9 Left reverse

set terminal pstex color
set output "Halpha.tex"

H(x)=1/(-x*log(x)-(1-x)*log (1-x))*log(2)

set xlabel '$\alpha$'
set ylabel '$1/H(\alpha)$'

plot [0:1][0:10] H(x) notitle w l lt 1 lw 4

######################################################################

set terminal pstex
set output "tradeoff-1-3.tex"
set ylabel '$\mbox{cost}(\alpha)$'

g(x,b)=1/(-x*log(x)-(1-x)*log (1-x))*log(2)*(1*x+b*(1-x))

plot [0:1][0:8] g(x,3) notitle w l lt 1 lw 4

#######################################################################

set terminal pstex
set output "tradeoff-graph.tex"

g(x,b)=1/(-x*log(x)-(1-x)*log (1-x))*log(2)*(1*x+b*(1-x))

plot [0:1][0:8] \
   g(x,0)  notitle w l lt 1 lw 4, \
   g(x,1) notitle w l lt 1  lw 4, \
   g(x,2)  notitle w l lt 1 lw 4, \
   g(x,3) notitle w l lt 1  lw 4, \
   g(x,4)  notitle w l lt 1 lw 4, \
   g(x,5) notitle w l lt 1  lw 4, \
   g(x,6)  notitle w l lt 1 lw 4, \
   g(x,7) notitle w l lt 1  lw 4, \
   g(x,8)  notitle w l lt 1 lw 4, \
   g(x,9) notitle w l lt 1  lw 4, \
   g(x,10) notitle w l lt 1  lw 4, \
   g(x,11)  notitle w l lt 1 lw 4, \
   g(x,12) notitle w l lt 1  lw 4, \
   g(x,13)  notitle w l lt 1 lw 4, \
   g(x,14) notitle w l lt 1  lw 4, \
   g(x,15)  notitle w l lt 1 lw 4, \
   g(x,16) notitle w l lt 1  lw 4, \
   g(x,17)  notitle w l lt 1 lw 4, \
   g(x,18) notitle w l lt 1  lw 4, \
   g(x,19)  notitle w l lt 1 lw 4, \
   g(x,20) notitle w l lt 1  lw 4, \
   g(x,21)  notitle w l lt 1 lw 4, \
   g(x,22) notitle w l lt 1  lw 4, \
   g(x,23)  notitle w l lt 1 lw 4, \
   g(x,24) notitle w l lt 1  lw 4, \
   g(x,25)  notitle w l lt 1 lw 4, \
   g(x,26) notitle w l lt 1  lw 4, \
   g(x,27)  notitle w l lt 1 lw 4, \
   g(x,28) notitle w l lt 1 lw 4

######################################################################
# Experimental plots
######################################################################

# Medium size = 100.000 elements
# Small size = 20.000 elements
# Timings are for 2.000.000 random elements

set terminal pstex color
set output "veb_comps.tex"
set xlabel '$\alpha$'
set ylabel 'Comparisons'
set yrange [0:300]
plot "small_plots/vEB.plot" using 1:($3/2000000) notitle


set terminal pstex color
set output "veb_time.tex"
set xlabel '$\alpha$'
set ylabel 'Running time, $10^{-6}$ sec'
set yrange [0.12:0.15]
#set autoscale y
#plot "small_plots/vEB.plot" using 1:($2/2) notitle
plot "small_plots/vEB.plot" using 1:($2/2) notitle


set terminal pstex color
set output "veb_mispred.tex"
set xlabel '$\alpha$'
set ylabel 'Branch mispredictions'
set autoscale y
plot "small_plots/vEB.plot" using 1:($4/2000000) notitle


set terminal pstex color
set output "time_simple.tex"
set xlabel '$\alpha$'
set ylabel 'Running time, $10^{-6}$ sec'
set yrange [0.1:0.35]
plot "small_plots/DFSl.plot" using 1:($2/2) title "DFSl", \
     "small_plots/DFSr.plot" using 1:($2/2) title "DFSr", \
     "small_plots/BFS.plot" using 1:($2/2) title "BFS", \
     "small_plots/Rand.plot" using 1:($2/2) title "Random", \
     "small_plots/Inord.plot" using 1:($2/2) title "Inorder"


set terminal pstex color
set output "cache_simple.tex"
set yrange [0:15]
#set autoscale y
set xlabel '$\alpha$'
set ylabel 'Cache faults'
plot "small_plots/DFSl.plot" using 1:($5/2000000) title "DFSl", \
     "small_plots/DFSr.plot" using 1:($5/2000000) title "DFSr", \
     "small_plots/BFS.plot" using 1:($5/2000000) title "BFS", \
     "small_plots/Rand.plot" using 1:($5/2000000) title "Random", \
     "small_plots/Inord.plot" using 1:($5/2000000) title "Inorder"


set terminal pstex color
set output "time_blocked.tex"
set xlabel '$\alpha$'
set ylabel 'Running time, $10^{-6}$ sec'
#set autoscale y
set yrange [0.12:0.20]
plot "small_plots/DFSr.plot" using 1:($2/2) title "DFSr", \
     "small_plots/pqDFS2.plot" using 1:($2/2) title "pqDFS2", \
     "small_plots/pqDFS4.plot" using 1:($2/2) title "pqDFS4", \
     "small_plots/pqDFS8.plot" using 1:($2/2) title "pqDFS8", \
     "small_plots/vEB.plot" using 1:($2/2) title "vEB"
     

set terminal pstex color
set output "cache_blocked.tex"
set xlabel '$\alpha$'
set ylabel 'Cache faults'
#set autoscale y
set yrange [1.5:5]
plot "small_plots/DFSr.plot" using 1:($5/2000000) title "DFSr", \
     "small_plots/pqDFS2.plot" using 1:($5/2000000) title "pqDFS2", \
     "small_plots/pqDFS4.plot" using 1:($5/2000000) title "pqDFS4", \
     "small_plots/pqDFS8.plot" using 1:($5/2000000) title "pqDFS8", \
     "small_plots/vEB.plot" using 1:($5/2000000) title "vEB"
     



